@@ -62,7 +62,7 @@ upgrade the file.
 
 =cut
 
-our $VERSION = '1.09';
+our $VERSION = '1.11';
 
 =pod
 
@@ -176,6 +176,10 @@ my %CONVERTER = (
 	my OSPF::LSDB $self = shift;
 	$self->{ospf}{version} = 1.0;
     },
+    1.1 => sub {
+	my OSPF::LSDB $self = shift;
+	$self->{ospf}{version} = 1.1;
+    },
 );
 
 =pod
